<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

use CRM_Stripe_ExtensionUtil as E;

/**
 * Stripe.Importcharges
 *
 * @param array $spec description of fields supported by this API call
 */
function _civicrm_api3_stripe_importcharge_spec(&$spec) {
  $spec['ppid']['title'] = E::ts('Payment Processor ID');
  $spec['ppid']['type'] = CRM_Utils_Type::T_INT;
  $spec['ppid']['api.required'] = TRUE;
  $spec['contact_id']['title'] = E::ts('Contact ID');
  $spec['contact_id']['description'] = E::ts('If not specified this will be determined from the "customer" on the charge - a StripeCustomer record must exist in CiviCRM');
  $spec['contact_id']['type'] = CRM_Utils_Type::T_INT;
  $spec['contact_id']['api.required'] = FALSE;
  $spec['charge']['title'] = E::ts('Stripe Charge ID');
  $spec['charge']['description'] = E::ts('The Charge ID to import');
  $spec['charge']['type'] = CRM_Utils_Type::T_STRING;
  $spec['charge']['api.required'] = TRUE;
  $spec['financial_type_id'] = [
    'title' => E::ts('Financial Type ID'),
    'type' => CRM_Utils_Type::T_STRING,
    'pseudoconstant' => [
      'table' => 'civicrm_financial_type',
      'keyColumn' => 'id',
      'labelColumn' => 'name',
    ],
    'api.default' => 1,
  ];
  $spec['payment_instrument_id'] = [
    'title' => E::ts('Payment Instrument ID'),
    'type' => CRM_Utils_Type::T_STRING,
    'api.default' => 1,
  ];
  $spec['contribution_source'] = [
    'title' => 'Contribution Source (optional description for contribution)',
    'type' => CRM_Utils_Type::T_STRING,
  ];
  $spec['contribution_id']['title'] = E::ts('Optionally, provide contribution ID of existing contribution you want to link to.');
  $spec['contribution_id']['type'] = CRM_Utils_Type::T_INT;

}

/**
 * Stripe.Importcharges API
 *
 * @param array $params
 *
 * @return array
 * @throws \CiviCRM_API3_Exception
 * @throws \Stripe\Exception\UnknownApiErrorException
 */
function civicrm_api3_stripe_importcharge($params) {
  $chargeImport = new \Civi\StripeImport\Charge();
  $chargeImport->setPaymentProcessorID($params['ppid']);
  $chargeImport->setStripeChargeID($params['charge']);
  if (!empty($params['contact_id'])) {
    $chargeImport->setContactID($params['contact_id']);
  }
  if (!empty($params['contribution_source'])) {
    $chargeImport->setDescription($params['contribution_source']);
  }
  if (!empty($params['contribution_id'])) {
    $chargeImport->setContributionID($params['contribution_id']);
  }
  $chargeImport->setFinancialTypeID($params['financial_type_id']);
  $chargeImport->setPaymentInstrumentID($params['payment_instrument_id']);
  $result = $chargeImport->importOne();
  return civicrm_api3_create_success($result);
}
